echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Required
[[ $(command -v cmake) == "" ]] && echo "Installing cmake" && extension --install cmake && echo "Finished cmake"

if [ $BUILD_ALL == "false" ] && [ $(cat /etc/extension/installed_version.list | grep spirv_headers | cut -d \= -f 2) != "1.4.321.0" ]; then
	echo "spirv_headers" 								>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "spirv_headers" 								>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
